# Vedant CLI

A fast command-line tool that prints the directory tree of the current folder.

## Install (recommended)
```bash
pipx install vedant
```

## Install (not recommended)
```bash
pip install vedant
```

## Install (for local development)

```bash
pip install -e .
```